==> pymc-5.1.0.tar.gz: pymc-5.1.0/docs/source/learn/books.md <==
(books)=
# Books
:::::{container} full-width
::::{grid} 1 2 2 3
:gutter: 3

:::{grid-item-card} Bayesian Modeling and Computation in Python
:img-top: https://bayesiancomputationbook.com/_images/Cover.jpg

By Osvaldo Martin, Ravin Kumar and Junpeng Lao

Hands on approach with PyMC and ArviZ focusing on the practice of applied statistics.

[Website + code](https://bayesiancomputationbook.com/welcome.html)

:::

:::{grid-item-card} Bayesian Methods for Hackers
:img-top: https://camo.githubusercontent.com/4a0aca82ca82efab71747d00db30f3a68de98e82/687474703a2f2f692e696d6775722e636f6d2f36444b596250622e706e673f31
By Cameron Davidson-Pilon

The "hacker" in the title  means learn-as-you-code. This hands-on introduction teaches intuitive definitions of the Bayesian approach to statistics, worklflow and decision-making by applying them using PyMC.

[Github repo](https://github.com/CamDavidsonPilon/Probabilistic-Programming-and-Bayesian-Methods-for-Hackers)

[Project homepage](http://camdavidsonpilon.github.io/Probabilistic-Programming-and-Bayesian-Methods-for-Hackers/)

:::

:::{grid-item-card} Bayesian Analysis with Python
:img-top: https://raw.githubusercontent.com/aloctavodia/BAP/master/Cover.png

By Osvaldo Martin


A great introductory book written by a maintainer of PyMC. It provides a hands-on introduction to the main concepts of Bayesian statistics using synthetic and real data sets. Mastering the concepts in this book is a great foundation to pursue more advanced knowledge.

[Book website](https://www.packtpub.com/big-data-and-business-intelligence/bayesian-analysis-python-second-edition)

[Code and errata in PyMC 3.x](https://github.com/aloctavodia/BAP)
:::

:::{grid-item-card} Doing Bayesian Data Analysis
:img-top: https://jkkweb.sitehost.iu.edu/DoingBayesianDataAnalysis/DBDA2Ecover.png

By John K. Kruschke


Principled introduction to Bayesian data analysis, with practical exercises. The book's original examples are coded in R, but notebooks with a PyMC port of the code are available through the links below.

[Book website](https://sites.google.com/site/doingbayesiandataanalysis/home)

[PyMC 3.x port of the second edition's code](https://github.com/JWarmenhoven/DBDA-python)

:::

:::{grid-item-card} Statistical Rethinking
:img-top: http://xcelab.net/rm/wp-content/uploads/2012/01/9781482253443-191x300.jpg

By Richard McElreath

A Bayesian Course with Examples in R and Stan.

[Book website](http://xcelab.net/rm/statistical-rethinking/)

[PyMC 3.x port of the code](https://github.com/pymc-devs/resources/tree/master/Rethinking)

:::

:::{grid-item-card} Bayesian Cognitive Modeling: A Practical Course
:img-top: https://images-na.ssl-images-amazon.com/images/I/51K33XI2I8L._SX330_BO1,204,203,200_.jpg

By Michael Lee and Eric-Jan Wagenmakers

Focused on using Bayesian statistics in cognitive modeling.

[Book website](https://bayesmodels.com/)

[PyMC 3.x implementations](https://github.com/pymc-devs/resources/tree/master/BCM)
:::

:::{grid-item-card} Bayesian Data Analysis
:img-top: http://www.stat.columbia.edu/~gelman/book/bda_cover.png

By Andrew Gelman, John Carlin, Hal Stern, David Dunson, Aki Vehtari, and Donald Rubin

A comprehensive, standard, and wonderful textbook on Bayesian methods.

[Book website](https://www.stat.columbia.edu/~gelman/book/)

[Examples and exercises implemented in PyMC 3.x](https://github.com/pymc-devs/resources/tree/master/BDA3)

::::
:::::

==> pymc-5.3.1.tar.gz: pymc-5.3.1/docs/source/learn/books.md <==
(books)=
# Books
:::::{container} full-width
::::{grid} 1 2 2 3
:gutter: 3

:::{grid-item-card} Bayesian Modeling and Computation in Python
:img-top: https://bayesiancomputationbook.com/_images/Cover.jpg

By Osvaldo Martin, Ravin Kumar and Junpeng Lao

Hands on approach with PyMC and ArviZ focusing on the practice of applied statistics.

[Website + code](https://bayesiancomputationbook.com/welcome.html)

:::

:::{grid-item-card} Bayesian Methods for Hackers
:img-top: https://camo.githubusercontent.com/4a0aca82ca82efab71747d00db30f3a68de98e82/687474703a2f2f692e696d6775722e636f6d2f36444b596250622e706e673f31
By Cameron Davidson-Pilon

The "hacker" in the title  means learn-as-you-code. This hands-on introduction teaches intuitive definitions of the Bayesian approach to statistics, worklflow and decision-making by applying them using PyMC.

[Github repo](https://github.com/CamDavidsonPilon/Probabilistic-Programming-and-Bayesian-Methods-for-Hackers)

[Project homepage](http://camdavidsonpilon.github.io/Probabilistic-Programming-and-Bayesian-Methods-for-Hackers/)

:::

:::{grid-item-card} Bayesian Analysis with Python
:img-top: https://aloctavodia.github.io/img/BAP.jpg

By Osvaldo Martin


A great introductory book written by a maintainer of PyMC. It provides a hands-on introduction to the main concepts of Bayesian statistics using synthetic and real data sets. Mastering the concepts in this book is a great foundation to pursue more advanced knowledge.

[Book website](https://www.packtpub.com/big-data-and-business-intelligence/bayesian-analysis-python-second-edition)

[Code and errata in PyMC 3.x](https://github.com/aloctavodia/BAP)
:::

:::{grid-item-card} Doing Bayesian Data Analysis
:img-top: https://jkkweb.sitehost.iu.edu/DoingBayesianDataAnalysis/DBDA2Ecover.png

By John K. Kruschke


Principled introduction to Bayesian data analysis, with practical exercises. The book's original examples are coded in R, but notebooks with a PyMC port of the code are available through the links below.

[Book website](https://sites.google.com/site/doingbayesiandataanalysis/home)

[PyMC port of the second edition's code](https://github.com/cluhmann/DBDA-python)

:::

:::{grid-item-card} Statistical Rethinking
:img-top: http://xcelab.net/rm/wp-content/uploads/2012/01/9781482253443-191x300.jpg

By Richard McElreath

A Bayesian Course with Examples in R and Stan.

[Book website](http://xcelab.net/rm/statistical-rethinking/)

[PyMC 3.x port of the code](https://github.com/pymc-devs/resources/tree/master/Rethinking)

:::

:::{grid-item-card} Bayesian Cognitive Modeling: A Practical Course
:img-top: https://images-na.ssl-images-amazon.com/images/I/51K33XI2I8L._SX330_BO1,204,203,200_.jpg

By Michael Lee and Eric-Jan Wagenmakers

Focused on using Bayesian statistics in cognitive modeling.

[Book website](https://bayesmodels.com/)

[PyMC 3.x implementations](https://github.com/pymc-devs/resources/tree/master/BCM)
:::

:::{grid-item-card} Bayesian Data Analysis
:img-top: https://www.stat.columbia.edu/~gelman/book/bda_cover.png

By Andrew Gelman, John Carlin, Hal Stern, David Dunson, Aki Vehtari, and Donald Rubin

A comprehensive, standard, and wonderful textbook on Bayesian methods.

[Book website](https://www.stat.columbia.edu/~gelman/book/)

[Examples and exercises implemented in PyMC 3.x](https://github.com/pymc-devs/resources/tree/master/BDA3)

::::
:::::
